@@ -9,7 +9,7 @@ from lightwood.mixer.base import BaseMixer
 from lightwood.ensemble.base import BaseEnsemble
 from lightwood.api.types import PredictionArguments
 from lightwood.data.encoded_ds import EncodedDs
-from lightwood.helpers.general import evaluate_accuracy
+from mindsdb_evaluator import evaluate_accuracies
 from type_infer.dtype import dtype
 
 
@@ -34,7 +34,7 @@ class WeightedMeanEnsemble(BaseEnsemble):
         if fit:
             score_list = []
             for _, mixer in enumerate(mixers):
-                score_dict = evaluate_accuracy(
+                score_dict = evaluate_accuracies(
                     data.data_frame,
                     mixer(data, args)['prediction'],
                     target,
